<template>
  <div class="app-container">
     <el-row :gutter="20">
       <el-col :span="showMap ? 12 : 24" :xs="24">
        <AppTable ref="AppTable" selection :showDeptSearch="false" :url="'tower/device/list'" :tableColumns="tableColumns"
          :tableFilter="tableFilter">
          <template #operatorBox="{ row }">
            <el-button type="primary" plain icon="el-icon-plus" size="mini"
              @click="handleAdd">新增设备</el-button>
              <el-button type="info" plain icon="el-icon-upload2" size="mini" @click="handleImport">导入</el-button>
          </template>
          <template #operator="{ row }">
            <el-button size="mini" type="text" icon="el-icon-edit"
              @click.stop="handleUpdate(row)">修改</el-button>
            <el-button size="mini" type="text" icon="el-icon-delete"
              @click.stop="handleDelete(row)">删除</el-button>
          </template>
        </AppTable>
      </el-col>
       <el-col :span="12" :xs="24" v-if="showMap">
          <CesiumMap ></CesiumMap>
       </el-col>
     </el-row>
    
    <deviceDialog ref="deviceDialog" @on-submit="$refs.AppTable.getData()" :model_type="dict.type.model_type" ></deviceDialog>
    <deviceImportDialog ref="deviceImportDialog" @on-submit="$refs.AppTable.getData()" ></deviceImportDialog>
  </div>
</template>

<script>
import deviceDialog from './components/deviceDialog.vue';
import deviceImportDialog from './components/deviceImportDialog.vue';
import CesiumMap from "../../../utils/components/cesium-map.vue";
export default {
  name: "towers",
  dicts: ['model_type'],
  components: {
    deviceDialog,
    CesiumMap,
    deviceImportDialog
  },
  data() {
    return {
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      tableColumns: [
        {
          label: '设备名称',
          prop: 'deviceName'
        },
        {
          label: '所属线路',
          prop: 'belongingRoute'
        },
        {
          label: '朝向',
          prop: 'face'
        },
        {
          label: '操作',
          type: 'slot',
          slotName: 'operator',
          width: '330px'
        },
      ],
      tableFilter: [
        {
          title: '设备名称',
          placeholder: '请输入设备名称',
          fieldName: 'name',
          clearable: true,
          type: 'search',
        }
      ],
      showMap:false
    };
  },
  watch: {
  },
  created() {
  },
  mounted() {
  },
  methods: {
    // 添加数据
    handleAdd() {
      this.showMap  = false
      this.$refs.deviceDialog.show()
    },
    // 更新数据
    handleUpdate(row) {
      const ids = row.id || this.ids
      this.$refs.deviceDialog.show(ids)
    },
    // 删除数据
    handleDelete(row) {
      console.log(row)
      const ids = row.id || this.ids
      const name = row.name || ''
      this.$api.deleteByName('/tower/device', ids,name).then(res => {
        this.$refs.AppTable.getData()
      })
    },
    // 导入井excel表格
    handleImport () {
      this.$refs.deviceImportDialog.show()
    },
    // clickRow(row){
    //   console.log(row)
    //   this.showMap =true
    // },
  },
};
</script>

<style scoped>
.left-card {
  height: calc(100vh - 105px);
  overflow: auto;
}

.right-card {
  height: calc(100vh - 105px);
}
</style>
